FileRecordReadSubRequest

Struct FileRecordReadSubRequest 

pub struct FileRecordReadSubRequest {
    pub file_number: u16,
    pub record_number: u16,
    pub record_length: u16,
}
Parsed read sub-request from FC14 PDU data.

Represents a single object within a Read File Record (FC 0x14) request.

Fields

file_number: u16

The file number to be read (0x0001 to 0xFFFF).

record_number: u16

The starting record number within the file (0x0000 to 0x270F).

record_length: u16

The length of the record in number of 16-bit registers.